#
# spec file for package tree
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           tree
Version:        1.7.0
Release:        8.1
Summary:        File listing as a tree
License:        GPL-2.0+
Group:          Productivity/File utilities
Url:            http://mama.indstate.edu/users/ice/tree/
Source0:        http://mama.indstate.edu/users/ice/tree/src/%{name}-%{version}.tgz
Patch0:         %{name}-makefile.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Tree is a recursive directory listing command that produces a depth
indented listing of files, which is colorized ala dircolors if the
LS_COLORS environment variable is set and output is to tty.

%prep
%setup -q
%patch0

%build
make OPTFLAGS="%{optflags}" %{?_smp_mflags}

%install
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_mandir}/man1
install -m 644 doc/%{name}.1 %{buildroot}%{_mandir}/man1
install -m 755 %{name} %{buildroot}%{_bindir}

%files
%defattr(-,root,root)
%doc CHANGES LICENSE README
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1.gz

%changelog
* Tue Jun 10 2014 tampakrap@opensuse.org
- Update to 1.7.0:
  * Allow user/group names up to 32 characters before clipping.
  * Made -i compress XML and JSON output as much as possible by eliminating
    extraneous whitespace.
  * Added --caseinsensitive (renamed --ignore-case ala grep) flag so patterns
    match without regard to case, courtesy of Jason A Donenfeld.
  * Added --matchdirs option courtesy of Brian Mattern & Jason A. Donenfeld
    <Jason@zx2c4.com>.
  * Fixed possible buffer overflow on large uid/gids w/o user names/group
    names (Alexandre Wendling <alexandrerw@celepar.pr.gov.br>)
  * Added JSON support courtesy of Florian Sesser <fs@it-agenten.com>.
  * Fixed formatting error with HTML output when -L 1 specified. (Sascha Zorn
    <sascha.zorn@gmail.com>)
  * Added file size sorting (Philipp M?ller <philippausmuensing@googlemail.com>)
  * Added '--sort[=]<name>' option, ala ls.
  * Fixed OS X makefile problems (Ryan Hollis <theryanhollis@gmail.com>)
  * Fixed possible memory overflow in read_dir (path/lbuf not equal in size
    to pathsize/lbufsize.) (Han Hui <hanhui03@163.com>)
  * Fix S_ISDOOR/S_IFDOOR spelling mistake for Solaris. (Tim Mooney
    <Tim.Mooney@ndsu.edu>)
  * Make tree more reliably detect UTF-8 locales. (Mantas Mikulnas
    <grawity@gmail.com> and others.)
  * Return non-zero exit status on option errors, print usage to stdout when
    not an error, add the posix '--' option terminator, Change -S description
    to mean CP437 (console) output codes, not ASCII. (Ivan Shmakov
    <oneingray@gmail.com>)
- Use upstream tarball instead of a custom one
- Adjust the makefile patch accordingly:
  - Rename tree-dontstrip.patch to tree-makefile.patch,
    since the upstream makefile does not include the strip flag anymore in that line
  - Fix the CFLAGS and LDFLAGS accordingly
- Run spec-cleaner
* Mon Nov 21 2011 chris@computersalat.de
- update to 1.6.0
  * Re-org of code into multiple files, split HTML and Unix listdir()
    into separate functions, various code cleanups and optimizations.
  * Fixed a memory leak in listdir() when memory was allocated early
    and not freed before function exit.
  * Fixed possible buffer overflow where symbolic links are followed.
  * Fixed links printing "argetm" before the name of the link when the
    LINK setting for DIR_COLORS is set to target
    (Markus Schnalke <meillo@marmaro.de>)
  * More fully support dir colors -- added support for su, sg, tw, ow,
    & st options (and "do" in theory).
  * Use the environment variable "TREE_COLORS" instead of "LS_COLORS"
    for color information if it exists.
  * Added --si flag to print filesizes in SI (powers of 1000) units
    (Ulrich Eckhardt)
  * Added -Q to quote filenames in double quotes. Does not override
  - N or -q.
  * Control characters are no longer printed in carrot notation, but as
    backslashed octal, ala ls, except for codes 7-13 which are printed
    as \a, \b, \t, \n, \v, \f and \r respectively. Spaces and
    backslashes are also now backslashed as per ls, for better input to
    scripts unless -Q is in use (where "'s are backslashed.)
    (Ujjwal Kumar)
  * Added -U for unsorted listings (directory order).
  * Added -c for sorting by last status change (ala ls -c).
  * --dirsfirst is now a meta-sort and does not override -c, -v, -r
    or -t, but is disabled by -U.
  * After many requests, added the ability to process the entire tree
    before emitting output. Used for the new options --du, which works
    like the du command: sums the amount of space under each directory
    and prints a total amount used in the report and the --prune option
    which will prune all empty directories from the output (makes the -P
    option output much more readable.) It should be noted that this will
    be slow to output when processing large directory trees and can
    consume copious amounts of memory, use at your own peril.
  * Added -X option to emit the directory tree in XML format
    (turns colorization off always.)
  * Added --timefmt option to specify the format of time display
    (implies -D). Uses the strftime format.
- rework donstrip patch
* Tue Oct  4 2011 uli@suse.com
- cross-build fix: use %%__cc macro
* Tue May  4 2010 meissner@suse.de
- pass in OPTFLAGS seperately, so LARGEFILE support does not
  get lost. bnc#601779
* Mon Dec  7 2009 chris@computersalat.de
- New upstream version 1.5.3
- cleanup spec
  * removed ^#----
- reworked dontstrip patch
* Tue Jul  7 2009 chris@computersalat.de
- added Changes, Author
* Fri Jul  3 2009 kay.sievers@novell.com
- New upstream version 1.5.2.2
  Added -v option for version sorting
* Sat Apr 14 2007 kay.sievers@suse.de
- New upstream version 1.5.1
- install README, LICENCE
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Aug 11 2005 kasievers@suse.de
- New version 1.5
* Tue Aug  9 2005 mmj@suse.de
- Use $RPM_OPT_FLAGS
* Sun Jan 18 2004 mmj@suse.de
- Fix compound statements (gcc 3.4)
* Thu Oct 16 2003 mmj@suse.de
- Don't build as root
- Don't strip explicitly
* Thu May 22 2003 coolo@suse.de
- use BuildRoot
* Tue Jan 14 2003 nadvornik@suse.cz
- fixed multi-line string literals
* Fri Jan  5 2001 jj@suse.de
- initial version
- gzipped manpage in archive
- removed binary from archive
- explicit install by specfile instead of 'make install'
